@@ -53,3 +53,21 @@ pub fn gltf_embedded() {
     let cache = AssetCache::new("assets").unwrap();
     cache.load::<asset::Gltf>("test.gltf.box-embedded").unwrap();
 }
+
+#[cfg(feature = "gltf")]
+#[test]
+pub fn gltf_dir() {
+    let cache = AssetCache::new("assets").unwrap();
+    let dir = cache.load_dir::<asset::Gltf>("test.gltf", false).unwrap();
+
+    let mut ids: Vec<_> = dir.iter().map(|gltf| gltf.unwrap().id()).collect();
+    ids.sort_unstable();
+    assert_eq!(
+        ids,
+        [
+            "test.gltf.box",
+            "test.gltf.box-bin",
+            "test.gltf.box-embedded"
+        ]
+    )
+}
